Module sample

Module sample 

Strategies for generating values by taking samples of collections.

Note that the strategies in this module are not native combinators; that is, the input collection is not itself a strategy, but is rather fixed when the strategy is created.

Structs

Index
A stand-in for an index into a slice or similar collection or conceptually similar things.
IndexStrategy
Strategy to create Indexes.
IndexValueTree
ValueTree corresponding to IndexStrategy.
Select
Strategy to produce one value from a fixed collection of options.
SelectValueTree
ValueTree corresponding to Select.
Selector
A value for picking random values out of iterators.
SelectorStrategy
Strategy to create Selectors.
SelectorValueTree
ValueTree corresponding to SelectorStrategy.
SizeRange
The minimum and maximum range/bounds on the size of a collection. The interval must form a subset of [0, std::usize::MAX).
Subsequence
Strategy to generate Vecs by sampling a subsequence from another collection.
SubsequenceValueTree
ValueTree type for Subsequence.

Functions

select
Create a strategy which uniformly selects one value from values.
size_range
Creates a SizeRange from some value that is convertible into it.
subsequence
Sample subsequences whose size are within size from the given collection values.